package com.ynet.life.mvc.upload;

import cn.hutool.core.io.FileTypeUtil;
import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEConstance;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.data.KeyedCollection;
import com.ynet.gene.flow.GENEFlow;
import com.ynet.gene.log.GENELog;
import com.ynet.gene.session.Session;
import com.ynet.gene.transaction.GENETransactionManager;
import com.ynet.gene.web.multipart.GENEMultipartHttpServletRequest;
import com.ynet.gene.web.multipart.MultipartHttpServletRequest;
import com.ynet.gene.web.multipart.UploadStatusListener;
import com.ynet.gene.web.multipart.implement.GENEMultipartFile;
import com.ynet.gene.web.servlet.ModelAndView;
import com.ynet.gene.web.servlet.mvc.GENEFlowExecuteResult;
import com.ynet.life.base.LifeErrorInfo;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.MVCEntity;
import com.ynet.life.base.TEntity;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.exception.UploadFileFailedException;
import com.ynet.life.file.LifeFile;
import com.ynet.life.util.RadomUtil;
import java.io.File;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Random;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import org.apache.commons.fileupload.FileItem;
import org.apache.commons.fileupload.FileUploadBase;
import org.apache.commons.fileupload.FileUploadException;
import org.apache.commons.fileupload.disk.DiskFileItemFactory;
import org.apache.commons.fileupload.servlet.ServletFileUpload;
import org.apache.commons.lang.StringUtils;

/* loaded from: com_ynet_life_mvc_upload.jar:com/ynet/life/mvc/upload/MultiSingleFileUploadRequestController.class */
public class MultiSingleFileUploadRequestController extends UploadController {
    private static final String ERROR_CODE_FIELD = "errorCodeField";
    private static final String ERROR_MSG_FIELD = "errorMsgField";
    private static final String DEFAULT_ERROR_CODE = "EBLN0000";
    private static final String PARAM_CHECK_CODE_NAME = "checkCode";
    private static final String PARAM_SESSION_OBJECT_NAME = "verifyObj";
    private static final String PARAM_SESSION_VERIFY_OBJECT_TIME = "session_verifyObjTime";
    private static final String dynamicFolderName = "remoteFilePath";
    private long maxFileSize = 10485760;
    private int bufferSize = 10240;
    private String tempFileFolder = null;
    private String uploadFileFolder = null;
    private boolean tmpFile = true;
    private Map mvcMap = new HashMap();
    long verifyObjTimeOut = 120000;

    @Override // com.ynet.life.mvc.upload.UploadController
    public ModelAndView doRequest(HttpServletRequest request, HttpServletResponse response) throws Exception {
        String ec;
        String errorMsg;
        String ec2;
        String errorMsg2;
        String ec3;
        String errorMsg3;
        String ec4;
        String errorMsg4;
        if (this.openMonitor) {
            this.accessInfo.newAccess();
        }
        Map model = new HashMap();
        UploadView uploadView = new UploadView();
        String mvcName = (String) request.getAttribute(GENEConstance.ATTR_ACTIONID);
        request.getParameter(TEntity.appKeyFieldname);
        try {
            if (isMultipart(request)) {
                GENEMultipartHttpServletRequest resolverMultipart = resolverMultipart(request, null);
                UploadRequest mvc = (UploadRequest) this.mvcMap.get(mvcName);
                Context sessionContext = null;
                if (mvc.isCheckSession()) {
                    try {
                        Session session = doSessionCheck(resolverMultipart, response);
                        if (session == null) {
                            Trace.logError("LifeSession", "Session not exist or timeout");
                            model.put(ERROR_CODE_FIELD, "EBLN1000");
                            return new ModelAndView(model, uploadView);
                        }
                        sessionContext = (Context) session.getAttribute(GENEConstance.ATTR_CONTEXT);
                        resolverMultipart.setAttribute(GENEConstance.GENE_SESSION, session);
                    } catch (Exception unused) {
                        Trace.logError("LifeSession", "Session not exist or timeout");
                        model.put(ERROR_CODE_FIELD, "EBLN1000");
                        return new ModelAndView(model, uploadView);
                    }
                }
                if (sessionContext != null) {
                    try {
                        preActionWork(resolverMultipart, sessionContext, mvc);
                    } catch (Exception e) {
                        Trace.logError("LifeFile", e.getMessage());
                        if (e instanceof GENEException) {
                            ec4 = e.getErrorCode();
                            String showMessage = e.getShowMessage();
                            errorMsg4 = showMessage;
                            if (showMessage == null || "".equals(errorMsg4)) {
                                LifeErrorInfo errorInfo = LifeStandard.getErrorInfo(ec4);
                                errorMsg4 = errorInfo != null ? errorInfo.getShowMsg() : "";
                            }
                        } else {
                            ec4 = DEFAULT_ERROR_CODE;
                            errorMsg4 = e.getMessage();
                        }
                        model.put(ERROR_CODE_FIELD, ec4);
                        model.put(ERROR_MSG_FIELD, errorMsg4);
                        return new ModelAndView(model, uploadView);
                    }
                }
                try {
                    GENEFlowExecuteResult result = executeGENELogic(sessionContext, resolverMultipart, response);
                    Context context = result.context;
                    KeyedCollection output = result.flow.getOutput(mvc.getOpId());
                    model.put(GENEConstance.ATTR_CONTEXT, context);
                    model.put(GENEConstance.ATTR_FLOW_OUTPUT, output);
                    if (result.e != null) {
                        Trace.logError(GENEConstance.GENE_MVC, result.e.getMessage(), result.e);
                        if (result.e instanceof GENEException) {
                            ec3 = result.e.getErrorCode();
                            String showMessage2 = result.e.getShowMessage();
                            errorMsg3 = showMessage2;
                            if (showMessage2 == null || "".equals(errorMsg3)) {
                                LifeErrorInfo errorInfo2 = LifeStandard.getErrorInfo(ec3);
                                errorMsg3 = errorInfo2 != null ? errorInfo2.getShowMsg() : "";
                            }
                        } else {
                            ec3 = DEFAULT_ERROR_CODE;
                            errorMsg3 = result.e.getMessage();
                        }
                        model.put(ERROR_CODE_FIELD, ec3);
                        model.put(ERROR_MSG_FIELD, errorMsg3);
                    }
                    return new ModelAndView(model, uploadView);
                } catch (Exception e2) {
                    Trace.logError("LifeFile", e2.getMessage());
                    if (e2 instanceof GENEException) {
                        ec2 = e2.getErrorCode();
                        String showMessage3 = e2.getShowMessage();
                        errorMsg2 = showMessage3;
                        if (showMessage3 == null || "".equals(errorMsg2)) {
                            LifeErrorInfo errorInfo3 = LifeStandard.getErrorInfo(ec2);
                            errorMsg2 = errorInfo3 != null ? errorInfo3.getShowMsg() : "";
                        }
                    } else {
                        ec2 = DEFAULT_ERROR_CODE;
                        errorMsg2 = e2.getMessage();
                    }
                    model.put(ERROR_CODE_FIELD, ec2);
                    model.put(ERROR_MSG_FIELD, errorMsg2);
                    return new ModelAndView(model, uploadView);
                }
            }
            Trace.logError("LifeFile", String.valueOf(mvcName) + "没有文件上传权限");
            model.put(ERROR_CODE_FIELD, DEFAULT_ERROR_CODE);
            model.put(ERROR_MSG_FIELD, String.valueOf(mvcName) + "没有文件上传权限");
            return new ModelAndView(model, uploadView);
        } catch (Exception e3) {
            Trace.logError("LifeFile", e3.getMessage());
            if (e3 instanceof GENEException) {
                ec = e3.getErrorCode();
                String showMessage4 = e3.getShowMessage();
                errorMsg = showMessage4;
                if (showMessage4 == null || "".equals(errorMsg)) {
                    LifeErrorInfo errorInfo4 = LifeStandard.getErrorInfo(ec);
                    errorMsg = errorInfo4 != null ? errorInfo4.getShowMsg() : "";
                }
            } else {
                ec = DEFAULT_ERROR_CODE;
                errorMsg = e3.getMessage();
            }
            model.put(ERROR_CODE_FIELD, ec);
            model.put(ERROR_MSG_FIELD, errorMsg);
            return new ModelAndView(model, uploadView);
        }
    }

    private boolean canPassTimeOut(HttpServletRequest request, String code) {
        String productMode = LifeStandard.getBankSettingsValue("productMode");
        if (!"true".equals(productMode)) {
            return true;
        }
        HttpSession cSession = request.getSession();
        Long session_verifyObjTime = (Long) cSession.getAttribute(PARAM_SESSION_VERIFY_OBJECT_TIME);
        long currentTime = System.currentTimeMillis();
        if (session_verifyObjTime == null) {
            return false;
        }
        boolean isTimeout = currentTime - session_verifyObjTime.longValue() < this.verifyObjTimeOut;
        cSession.removeAttribute(PARAM_SESSION_VERIFY_OBJECT_TIME);
        return isTimeout;
    }

    private boolean canPass(HttpServletRequest request, String code) {
        String productMode = LifeStandard.getBankSettingsValue("productMode");
        if (!"true".equals(productMode)) {
            return true;
        }
        System.out.println("===============".concat(String.valueOf(code)));
        request.getParameter("formId");
        HttpSession cSession = request.getSession();
        String verifyStr = (String) cSession.getAttribute(PARAM_SESSION_OBJECT_NAME);
        cSession.getAttribute("session_formid");
        cSession.removeAttribute(PARAM_SESSION_OBJECT_NAME);
        if (verifyStr != null && code != null && code.equalsIgnoreCase(verifyStr)) {
            return true;
        }
        return false;
    }

    @Override // com.ynet.life.mvc.upload.UploadController
    protected GENEFlowExecuteResult executeGENELogic(Context sessionContext, GENEMultipartHttpServletRequest request, HttpServletResponse response) {
        String mvcName = (String) request.getAttribute(GENEConstance.ATTR_ACTIONID);
        UploadRequest mvc = (UploadRequest) this.mvcMap.get(mvcName);
        GENEFlowExecuteResult result = new GENEFlowExecuteResult();
        GENETransactionManager transactionManager = null;
        String flowId = mvc.getBizId();
        GENELog.log(GENEConstance.GENE_MVC, GENELog.DEBUG, 0, "begin to execute flow " + flowId + " ...");
        String opId = mvc.getOpId();
        try {
            GENELog.log(GENEConstance.GENE_MVC, GENELog.DEBUG, 0, "Get flow " + flowId + "  from factory...");
            GENEFlow flow = this.geneFactory.getGENEFlow(flowId);
            result.flow = flow;
            Context context = (Context) flow.getContext().clone();
            result.context = context;
            if (sessionContext != null && context.getParentContextName() == null) {
                context.chainedTo(sessionContext);
            } else {
                GENELog.log(GENEConstance.GENE_MVC, GENELog.WARNING, 0, "The sessionContext is null , maybe a unvalid session request ...");
            }
            transactionManager = (GENETransactionManager) context.getService(GENEConstance.TRX_SVC_NAME);
            GENELog.log(GENEConstance.GENE_MVC, GENELog.DEBUG, 0, "Update the request data ...");
            doUpdateModel(request, context, flow, opId);
            doPreprocessModelData(request, context, flow, opId);
            addDataField(context, GENEConstance.SERVLET_REQUEST, request);
            preContextWork(request, sessionContext, context, mvc);
            String retValue = flow.execute(context, opId);
            if (transactionManager != null) {
                transactionManager.commit();
            }
            result.result = retValue;
        } catch (Exception e) {
            GENELog.log(GENEConstance.GENE_MVC, GENELog.ERROR, 0, "Failed to execute flow ".concat(String.valueOf(flowId)), e);
            result.e = e;
            if (transactionManager != null) {
                transactionManager.rollback();
            }
        }
        return result;
    }

    @Override // com.ynet.life.mvc.upload.UploadController
    public void addUploadRequest(UploadRequest mvc) {
        this.mvcMap.put(mvc.getId(), mvc);
    }

    @Override // com.ynet.life.mvc.upload.UploadController
    public boolean isMultipart(HttpServletRequest request) {
        return ServletFileUpload.isMultipartContent(request);
    }

    @Override // com.ynet.life.mvc.upload.UploadController
    public GENEMultipartHttpServletRequest resolverMultipart(HttpServletRequest request, UploadStatusListener listener) throws GENEException {
        String mvcName = (String) request.getAttribute(GENEConstance.ATTR_ACTIONID);
        UploadRequest mvc = (UploadRequest) this.mvcMap.get(mvcName);
        if (mvc == null) {
            Trace.logError("LifeFile", String.valueOf(mvcName) + "没有文件上传权限");
            throw new TranFailException(DEFAULT_ERROR_CODE, String.valueOf(mvcName) + "没有文件上传权限");
        }
        DiskFileItemFactory factory = new DiskFileItemFactory(this.bufferSize, new File(getTempUploadDir()));
        ServletFileUpload upload = new ServletFileUpload(factory);
        upload.setSizeMax(getMaxFileSize(mvc));
        try {
            List<FileItem> items = upload.parseRequest(request);
            Map parameters = new HashMap();
            Map fileMap = new HashMap();
            String filePathTemp = "";
            try {
                checkFile(items, request);
            } catch (IOException unused) {
            }
            SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMdd");
            String fileFolder = String.valueOf("") + sdf.format(new Date());
            System.out.println("=========================fileFolder:".concat(String.valueOf(fileFolder)));
            addParameter(dynamicFolderName, fileFolder, parameters);
            String multiFileName = "";
            String multiModifyFileName = "";
            String originalFileName = "";
            for (FileItem item : items) {
                String fieldName = item.getFieldName();
                if (!item.isFormField()) {
                    String name = item.getName();
                    originalFileName = name;
                    if (StringUtils.isNotEmpty(name) && originalFileName.indexOf("\\") >= 0) {
                        originalFileName = StringUtils.substringAfterLast(originalFileName, "\\");
                    }
                    if (originalFileName.length() > 0) {
                        mvc.validateType(item);
                        String uploadPath = getUploadDirectory();
                        filePathTemp = uploadPath;
                        String finalFileName = getFileName(originalFileName);
                        String uploadFolder = String.valueOf(uploadPath) + fileFolder;
                        String finalFilePathName = String.valueOf(uploadPath) + fileFolder + LifeFile.DIR_SEPARATOR + originalFileName;
                        File uploadedFile = new File(uploadFolder);
                        if (!uploadedFile.exists()) {
                            uploadedFile.mkdirs();
                        }
                        try {
                            File file = new File(finalFilePathName);
                            for (int i = 0; i < 99 && file.exists(); i++) {
                                String prefix = "_" + RadomUtil.generateString(5);
                                String str1 = originalFileName.substring(0, originalFileName.lastIndexOf("."));
                                String str = originalFileName;
                                String str2 = str.substring(str.lastIndexOf(".") + 1);
                                if (str1 != originalFileName && str2 != originalFileName) {
                                    originalFileName = String.valueOf(str1) + prefix + "." + str2;
                                } else {
                                    originalFileName = String.valueOf(prefix) + originalFileName;
                                }
                                finalFilePathName = String.valueOf(uploadPath) + fileFolder + LifeFile.DIR_SEPARATOR + originalFileName;
                                file = new File(finalFilePathName);
                            }
                            item.write(file);
                            long fileSize = item.getSize();
                            String str3 = originalFileName;
                            String str4 = str3.substring(str3.lastIndexOf(".") + 1);
                            if (str4.equalsIgnoreCase("jpg") || str4.equalsIgnoreCase("jpeg") || str4.equalsIgnoreCase("png")) {
                                int flag = 0;
                                if (fileSize > 2097152) {
                                    String str5 = finalFilePathName;
                                    flag = ReduceImg.reduceImg(str5, str5, 500, 500, Float.valueOf(2097152.0f / ((float) fileSize)));
                                }
                                if (flag < 0) {
                                    if (flag == -1) {
                                        throw new Exception("不支持此格式的压缩,请压缩至2M以下再上传");
                                    }
                                    if (flag == -2) {
                                        throw new Exception("压缩失败");
                                    }
                                    throw new Exception("压缩失败");
                                }
                            }
                            if (mvc.isAbsoluteFile()) {
                                fileMap.put(fieldName, new GENEMultipartFile(fieldName, finalFilePathName, originalFileName));
                            } else {
                                fileMap.put(fieldName, new GENEMultipartFile(fieldName, finalFileName, originalFileName));
                            }
                            addParameter(fieldName, originalFileName, parameters);
                            multiFileName = String.valueOf(multiFileName == "" ? "" : String.valueOf(multiFileName) + ",") + originalFileName;
                            System.out.println("=========================multiFileName:".concat(String.valueOf(multiFileName)));
                        } catch (Exception ex) {
                            if (uploadedFile.exists()) {
                                uploadedFile.delete();
                            }
                            Trace.logError("LifeFile", "文件[" + finalFilePathName + "]上传失败," + ex.getMessage(), ex);
                            throw new TranFailException(DEFAULT_ERROR_CODE, "文件[" + originalFileName + "]上传失败," + ex.getMessage(), ex);
                        }
                    }
                }
                if (item.isFormField()) {
                    try {
                        String fieldValue = item.getString("UTF-8");
                        if (fieldName.equals("TempPathList.path")) {
                            multiModifyFileName = fieldValue;
                        } else {
                            addParameter(fieldName, fieldValue, parameters);
                        }
                    } catch (UnsupportedEncodingException e) {
                        Trace.logWarning("LifeFile", "不支持的编码", e);
                    }
                }
            }
            if (!multiFileName.equals("")) {
                String[] mmfArr = multiModifyFileName.split(",");
                String[] mfnArr = multiFileName.split(",");
                String[] newArr = new String[mmfArr.length];
                if (mmfArr.length > 0) {
                    for (int i2 = 0; i2 < mmfArr.length; i2++) {
                        if (i2 + mfnArr.length >= mmfArr.length) {
                            newArr[i2] = mfnArr[(i2 + mfnArr.length) - mmfArr.length];
                        } else {
                            newArr[i2] = mmfArr[i2];
                        }
                    }
                }
                String newMultiFileName = "";
                for (int i3 = 0; i3 < newArr.length; i3++) {
                    newMultiFileName = String.valueOf(newMultiFileName) + (newMultiFileName.equals("") ? newArr[i3] : "," + newArr[i3]);
                }
                String multiFileName2 = newMultiFileName;
                addParameter("TempPathList.path", multiFileName2, parameters);
            }
            String returnPath = String.valueOf(filePathTemp) + fileFolder;
            int index = returnPath.indexOf("upload");
            String returnPath2 = returnPath.substring(index);
            fileMap.put("fileFolder", fileFolder);
            fileMap.put("filePath", returnPath2);
            fileMap.put("fileName", originalFileName);
            return new GENEMultipartHttpServletRequest(request, parameters, fileMap);
        } catch (FileUploadException ex2) {
            Trace.logError("LifeFile", "文件上传请求处理失败", ex2);
            throw new TranFailException(DEFAULT_ERROR_CODE, "文件上传请求处理失败", ex2);
        } catch (FileUploadBase.SizeLimitExceededException ex3) {
            Trace.logError("LifeFile", "文件上传大小超过" + ((getMaxFileSize(mvc) / 1024) / 1024) + "M", ex3);
            throw new UploadFileFailedException("文件上传大小超过" + ((getMaxFileSize(mvc) / 1024) / 1024) + "M");
        }
    }

    public boolean checkFile(List items, HttpServletRequest request) throws IOException, TranFailException {
        Iterator iterator = items.iterator();
        while (iterator.hasNext()) {
            FileItem item = (FileItem) iterator.next();
            String fieldName = item.getFieldName();
            if (!item.isFormField()) {
                String originalFileName = item.getName();
                if (originalFileName.length() > 0) {
                    item.getSize();
                    String str = originalFileName.substring(originalFileName.lastIndexOf(".") + 1);
                    if (str.equalsIgnoreCase("jpg") || str.equalsIgnoreCase("jpeg") || str.equalsIgnoreCase("png")) {
                        String fileType = FileTypeUtil.getType(item.getInputStream());
                        if (fileType == null || (!fileType.equalsIgnoreCase("jpg") && !fileType.equalsIgnoreCase("jpeg") && !fileType.equalsIgnoreCase("png"))) {
                            throw new TranFailException("fileError", "非法图片");
                        }
                    }
                } else {
                    continue;
                }
            } else if (item.isFormField() && fieldName.equals(PARAM_CHECK_CODE_NAME)) {
                String fieldValue = item.getString("UTF-8");
                String productMode = LifeStandard.getBankSettingsValue("productMode");
                if ("true".equals(productMode) && !canPass(request, fieldValue)) {
                    throw new TranFailException("EBLN5006", "验证码输入有误，请重新输入验证码");
                }
            }
        }
        return true;
    }

    @Override // com.ynet.life.mvc.upload.UploadController
    public void cleanup(MultipartHttpServletRequest request) {
    }

    private long getMaxFileSize(UploadRequest mvc) {
        long mvcMaxSize = mvc.getMaxFileSize();
        return mvcMaxSize > 0 ? mvcMaxSize : this.maxFileSize;
    }

    private void checkFolder(String folderPath) {
        if (!new File(folderPath).isDirectory()) {
            Trace.logError("LifeFile", "本地目录--->" + folderPath + " 不可用");
            LifeFile.makeMultiDirectory(folderPath);
        }
    }

    private void addParameter(String key, String value, Map map) {
        Object preValueObj = map.get(key);
        if (preValueObj == null) {
            map.put(key, new String[]{value});
            return;
        }
        int len = ((String[]) preValueObj).length;
        String[] sArr = new String[len + 1];
        System.arraycopy(preValueObj, 0, sArr, 0, len);
        sArr[len] = value.trim();
        map.put(key, sArr);
    }

    @Override // com.ynet.life.mvc.upload.UploadController
    protected String getUploadDirectory() {
        String dir;
        if (!this.tmpFile) {
            dir = String.valueOf(LifeFile.getFileRootPath()) + this.uploadFileFolder + LifeFile.DIR_SEPARATOR;
        } else {
            dir = String.valueOf(LifeFile.getTempFileRootPath()) + this.uploadFileFolder + LifeFile.DIR_SEPARATOR + LifeStandard.getServerTime("yyyyMMdd") + LifeFile.DIR_SEPARATOR;
        }
        checkFolder(dir);
        return dir;
    }

    @Override // com.ynet.life.mvc.upload.UploadController
    protected String getTempUploadDir() {
        String dir = String.valueOf(LifeFile.getTempFileRootPath()) + this.tempFileFolder + LifeFile.DIR_SEPARATOR;
        checkFolder(dir);
        return dir;
    }

    @Override // com.ynet.life.mvc.upload.UploadController
    protected String getFileName(String fileName) {
        String generateName = String.valueOf(LifeStandard.getServerTime("yyyyMMddHHmmssSSS")) + new Random().nextInt(1000);
        int dotPos = fileName.lastIndexOf(".");
        if (dotPos > 0) {
            return String.valueOf(generateName) + fileName.substring(dotPos);
        }
        return generateName;
    }

    @Override // com.ynet.life.mvc.upload.UploadController
    public void setMaxFileSize(String maxFileSize) {
        this.maxFileSize = Long.parseLong(maxFileSize);
    }

    @Override // com.ynet.life.mvc.upload.UploadController
    public void setBufferSize(String bufferSize) {
        this.bufferSize = Integer.parseInt(bufferSize);
    }

    @Override // com.ynet.life.mvc.upload.UploadController
    public void setTempFileFolder(String tempFileFolder) {
        this.tempFileFolder = tempFileFolder;
    }

    @Override // com.ynet.life.mvc.upload.UploadController
    public void setUploadFileFolder(String uploadFileFolder) {
        this.uploadFileFolder = uploadFileFolder;
    }

    @Override // com.ynet.life.mvc.upload.UploadController
    public boolean isInCharge(HttpServletRequest request) {
        String actionId = (String) request.getAttribute(GENEConstance.ATTR_ACTIONID);
        if (this.mvcMap != null && this.mvcMap.get(actionId) != null) {
            return true;
        }
        return false;
    }

    @Override // com.ynet.life.mvc.upload.UploadController
    protected void preActionWork(HttpServletRequest request, Context sessionContext, UploadRequest mvc) throws TranFailException {
    }

    @Override // com.ynet.life.mvc.upload.UploadController
    protected void pstActionWork(HttpServletRequest request, Context sessionContext, UploadRequest mvc, Throwable throwable) throws TranFailException {
    }

    @Override // com.ynet.life.mvc.upload.UploadController
    protected void preContextWork(HttpServletRequest request, Context sessionContext, Context context, UploadRequest mvc) throws TranFailException {
        if (mvc != null && mvc.isCheckSession()) {
            addBusinessInfo(request, context, mvc);
        }
    }

    @Override // com.ynet.life.mvc.upload.UploadController
    public boolean isTmpFile() {
        return this.tmpFile;
    }

    @Override // com.ynet.life.mvc.upload.UploadController
    public void setTmpFile(boolean tmpFile) {
        this.tmpFile = tmpFile;
    }

    @Override // com.ynet.life.mvc.upload.UploadController
    public ModelAndView handleException(HttpServletRequest request, HttpServletResponse response, Exception e) {
        Map model = new HashMap();
        model.put(GENEConstance.ATTR_EXCEPTION, e);
        return new ModelAndView(model, new UploadView());
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v11, types: [boolean] */
    /* JADX WARN: Type inference failed for: r0v15, types: [com.ynet.life.cache.Cache] */
    private void addBusinessInfo(HttpServletRequest request, Context context, UploadRequest mvc) throws TranFailException {
        MVCEntity mvcEntity;
        if (mvc != null) {
            String appKey = request.getParameter(TEntity.appKeyFieldname);
            Session session = (Session) this.sessionManager.getSessions().get(appKey);
            String cacheServiceFlag = LifeStandard.getSelfDefineSettingsValue("cacheServiceFlag");
            TranFailException equals = "true".equals(cacheServiceFlag);
            if (equals != 0) {
                try {
                    equals = LifeStandard.getCache("sessionData_cache");
                    mvcEntity = (MVCEntity) equals.get(appKey);
                } catch (TranFailException e) {
                    equals.printStackTrace();
                    throw new TranFailException(e);
                }
            } else {
                mvcEntity = (MVCEntity) session.getAttribute(appKey);
            }
            mvcEntity.getBankId();
            mvcEntity.getChannel();
            request.getParameter(TEntity.responseFormat);
            request.getRequestURI();
            request.getMethod();
            context.put(TEntity.LOGIN_ID, mvcEntity.getLogonId());
            context.put(TEntity.USER_NAME, mvcEntity.getUserName());
            context.put(TEntity.USER_BELONGS_BRANCH, mvcEntity.getUserBelongsBranch());
            context.put(TEntity.USER_BRANCH_ID, mvcEntity.getUserBranchId());
            context.put(TEntity.BRANCHNAME, mvcEntity.getBranchName());
            context.put(TEntity.REGIONS_IDS, mvcEntity.getRegionIds());
            context.put(TEntity.USER_PHONE, mvcEntity.getUserPhone());
            context.put(TEntity.ROLE_ID, mvcEntity.getRoleId());
            context.put(TEntity.ROLE_TYPE, mvcEntity.getRoleType());
            context.put(TEntity.USER_ID, mvcEntity.getUserId());
            context.put(TEntity.COR_ORECODE, mvcEntity.getSession_orgCode());
            context.put(TEntity.CLASSNO, mvcEntity.getClassNo());
            context.put(TEntity.appKeyFieldname, appKey);
        }
    }
}
